_`umbra.managers.layoutsManager`
================================

.. automodule:: umbra.managers.layoutsManager

Module Attributes
-----------------

.. attribute:: umbra.managers.layoutsManager.LOGGER

Classes
-------

.. autoclass:: Layout
	:show-inheritance:
	:members:

.. autoclass:: LayoutsManager
	:show-inheritance:
	:members:

